# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rustplus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0erustplus.proto\x12\x08rustplus"`\n\nAppMessage\x12\'\n\x08response\x18\x01 \x01(\x0b\x32\x15.rustplus.AppResponse\x12)\n\tbroadcast\x18\x02 \x01(\x0b\x32\x16.rustplus.AppBroadcast"\x9b\x05\n\nAppRequest\x12\x0b\n\x03seq\x18\x01 \x02(\r\x12\x10\n\x08playerId\x18\x02 \x02(\x04\x12\x13\n\x0bplayerToken\x18\x03 \x02(\x05\x12\x10\n\x08\x65ntityId\x18\x04 \x01(\r\x12#\n\x07getInfo\x18\x08 \x01(\x0b\x32\x12.rustplus.AppEmpty\x12#\n\x07getTime\x18\t \x01(\x0b\x32\x12.rustplus.AppEmpty\x12"\n\x06getMap\x18\n \x01(\x0b\x32\x12.rustplus.AppEmpty\x12\'\n\x0bgetTeamInfo\x18\x0b \x01(\x0b\x32\x12.rustplus.AppEmpty\x12\'\n\x0bgetTeamChat\x18\x0c \x01(\x0b\x32\x12.rustplus.AppEmpty\x12\x31\n\x0fsendTeamMessage\x18\r \x01(\x0b\x32\x18.rustplus.AppSendMessage\x12)\n\rgetEntityInfo\x18\x0e \x01(\x0b\x32\x12.rustplus.AppEmpty\x12\x33\n\x0esetEntityValue\x18\x0f \x01(\x0b\x32\x1b.rustplus.AppSetEntityValue\x12-\n\x11\x63heckSubscription\x18\x10 \x01(\x0b\x32\x12.rustplus.AppEmpty\x12*\n\x0fsetSubscription\x18\x11 \x01(\x0b\x32\x11.rustplus.AppFlag\x12)\n\rgetMapMarkers\x18\x12 \x01(\x0b\x32\x12.rustplus.AppEmpty\x12\x37\n\x0egetCameraFrame\x18\x13 \x01(\x0b\x32\x1f.rustplus.AppCameraFrameRequest\x12\x35\n\x0fpromoteToLeader\x18\x14 \x01(\x0b\x32\x1c.rustplus.AppPromoteToLeader"!\n\x0e\x41ppSendMessage\x12\x0f\n\x07message\x18\x01 \x02(\t""\n\x11\x41ppSetEntityValue\x12\r\n\x05value\x18\x01 \x02(\x08":\n\x15\x41ppCameraFrameRequest\x12\x12\n\nidentifier\x18\x01 \x02(\t\x12\r\n\x05\x66rame\x18\x02 \x02(\r"%\n\x12\x41ppPromoteToLeader\x12\x0f\n\x07steamId\x18\x01 \x02(\x04"\xc1\x03\n\x0b\x41ppResponse\x12\x0b\n\x03seq\x18\x01 \x02(\r\x12%\n\x07success\x18\x04 \x01(\x0b\x32\x14.rustplus.AppSuccess\x12!\n\x05\x65rror\x18\x05 \x01(\x0b\x32\x12.rustplus.AppError\x12\x1f\n\x04info\x18\x06 \x01(\x0b\x32\x11.rustplus.AppInfo\x12\x1f\n\x04time\x18\x07 \x01(\x0b\x32\x11.rustplus.AppTime\x12\x1d\n\x03map\x18\x08 \x01(\x0b\x32\x10.rustplus.AppMap\x12\'\n\x08teamInfo\x18\t \x01(\x0b\x32\x15.rustplus.AppTeamInfo\x12\'\n\x08teamChat\x18\n \x01(\x0b\x32\x15.rustplus.AppTeamChat\x12+\n\nentityInfo\x18\x0b \x01(\x0b\x32\x17.rustplus.AppEntityInfo\x12\x1f\n\x04\x66lag\x18\x0c \x01(\x0b\x32\x11.rustplus.AppFlag\x12+\n\nmapMarkers\x18\r \x01(\x0b\x32\x17.rustplus.AppMapMarkers\x12-\n\x0b\x63\x61meraFrame\x18\x0e \x01(\x0b\x32\x18.rustplus.AppCameraFrame"\x9f\x01\n\x0c\x41ppBroadcast\x12-\n\x0bteamChanged\x18\x04 \x01(\x0b\x32\x18.rustplus.AppTeamChanged\x12-\n\x0bteamMessage\x18\x05 \x01(\x0b\x32\x18.rustplus.AppTeamMessage\x12\x31\n\rentityChanged\x18\x06 \x01(\x0b\x32\x1a.rustplus.AppEntityChanged"\n\n\x08\x41ppEmpty"\x0c\n\nAppSuccess"\x19\n\x08\x41ppError\x12\r\n\x05\x65rror\x18\x01 \x02(\t"\xc1\x01\n\x07\x41ppInfo\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0bheaderImage\x18\x02 \x02(\t\x12\x0b\n\x03url\x18\x03 \x02(\t\x12\x0b\n\x03map\x18\x04 \x02(\t\x12\x0f\n\x07mapSize\x18\x05 \x02(\r\x12\x10\n\x08wipeTime\x18\x06 \x02(\r\x12\x0f\n\x07players\x18\x07 \x02(\r\x12\x12\n\nmaxPlayers\x18\x08 \x02(\r\x12\x15\n\rqueuedPlayers\x18\t \x02(\r\x12\x0c\n\x04seed\x18\n \x01(\r\x12\x0c\n\x04salt\x18\x0b \x01(\r"e\n\x07\x41ppTime\x12\x18\n\x10\x64\x61yLengthMinutes\x18\x01 \x02(\x02\x12\x11\n\ttimeScale\x18\x02 \x02(\x02\x12\x0f\n\x07sunrise\x18\x03 \x02(\x02\x12\x0e\n\x06sunset\x18\x04 \x02(\x02\x12\x0c\n\x04time\x18\x05 \x02(\x02"\xc1\x01\n\x06\x41ppMap\x12\r\n\x05width\x18\x01 \x02(\r\x12\x0e\n\x06height\x18\x02 \x02(\r\x12\x10\n\x08jpgImage\x18\x03 \x02(\x0c\x12\x13\n\x0boceanMargin\x18\x04 \x02(\x05\x12,\n\tmonuments\x18\x05 \x03(\x0b\x32\x19.rustplus.AppMap.Monument\x12\x12\n\nbackground\x18\x06 \x01(\t\x1a/\n\x08Monument\x12\r\n\x05token\x18\x01 \x02(\t\x12\t\n\x01x\x18\x02 \x02(\x02\x12\t\n\x01y\x18\x03 \x02(\x02"\xea\x02\n\x0b\x41ppTeamInfo\x12\x15\n\rleaderSteamId\x18\x01 \x02(\x04\x12-\n\x07members\x18\x02 \x03(\x0b\x32\x1c.rustplus.AppTeamInfo.Member\x12,\n\x08mapNotes\x18\x03 \x03(\x0b\x32\x1a.rustplus.AppTeamInfo.Note\x12\x32\n\x0eleaderMapNotes\x18\x04 \x03(\x0b\x32\x1a.rustplus.AppTeamInfo.Note\x1a\x86\x01\n\x06Member\x12\x0f\n\x07steamId\x18\x01 \x02(\x04\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\t\n\x01x\x18\x03 \x02(\x02\x12\t\n\x01y\x18\x04 \x02(\x02\x12\x10\n\x08isOnline\x18\x05 \x02(\x08\x12\x11\n\tspawnTime\x18\x06 \x02(\r\x12\x0f\n\x07isAlive\x18\x07 \x02(\x08\x12\x11\n\tdeathTime\x18\x08 \x02(\r\x1a*\n\x04Note\x12\x0c\n\x04type\x18\x02 \x02(\x05\x12\t\n\x01x\x18\x03 \x02(\x02\x12\t\n\x01y\x18\x04 \x02(\x02"9\n\x0b\x41ppTeamChat\x12*\n\x08messages\x18\x01 \x03(\x0b\x32\x18.rustplus.AppChatMessage"]\n\x0e\x41ppChatMessage\x12\x0f\n\x07steamId\x18\x01 \x02(\x04\x12\x0c\n\x04name\x18\x02 \x02(\t\x12\x0f\n\x07message\x18\x03 \x02(\t\x12\r\n\x05\x63olor\x18\x04 \x02(\t\x12\x0c\n\x04time\x18\x05 \x02(\r"c\n\rAppEntityInfo\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.rustplus.AppEntityType\x12+\n\x07payload\x18\x03 \x02(\x0b\x32\x1a.rustplus.AppEntityPayload"\xd7\x01\n\x10\x41ppEntityPayload\x12\r\n\x05value\x18\x01 \x01(\x08\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.rustplus.AppEntityPayload.Item\x12\x10\n\x08\x63\x61pacity\x18\x03 \x01(\x05\x12\x15\n\rhasProtection\x18\x04 \x01(\x08\x12\x18\n\x10protectionExpiry\x18\x05 \x01(\r\x1a\x41\n\x04Item\x12\x0e\n\x06itemId\x18\x01 \x02(\x05\x12\x10\n\x08quantity\x18\x02 \x02(\x05\x12\x17\n\x0fitemIsBlueprint\x18\x03 \x02(\x08"\x18\n\x07\x41ppFlag\x12\r\n\x05value\x18\x01 \x02(\x08"5\n\rAppMapMarkers\x12$\n\x07markers\x18\x01 \x03(\x0b\x32\x13.rustplus.AppMarker"5\n\x07Vector4\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02"\xc3\x03\n\tAppMarker\x12\n\n\x02id\x18\x01 \x02(\r\x12%\n\x04type\x18\x02 \x02(\x0e\x32\x17.rustplus.AppMarkerType\x12\t\n\x01x\x18\x03 \x02(\x02\x12\t\n\x01y\x18\x04 \x02(\x02\x12\x0f\n\x07steamId\x18\x05 \x01(\x04\x12\x10\n\x08rotation\x18\x06 \x01(\x02\x12\x0e\n\x06radius\x18\x07 \x01(\x02\x12!\n\x06\x63olor1\x18\x08 \x01(\x0b\x32\x11.rustplus.Vector4\x12!\n\x06\x63olor2\x18\t \x01(\x0b\x32\x11.rustplus.Vector4\x12\r\n\x05\x61lpha\x18\n \x01(\x02\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x31\n\nsellOrders\x18\r \x03(\x0b\x32\x1d.rustplus.AppMarker.SellOrder\x1a\xa3\x01\n\tSellOrder\x12\x0e\n\x06itemId\x18\x01 \x02(\x05\x12\x10\n\x08quantity\x18\x02 \x02(\x05\x12\x12\n\ncurrencyId\x18\x03 \x02(\x05\x12\x13\n\x0b\x63ostPerItem\x18\x04 \x02(\x05\x12\x15\n\ramountInStock\x18\x05 \x02(\x05\x12\x17\n\x0fitemIsBlueprint\x18\x06 \x02(\x08\x12\x1b\n\x13\x63urrencyIsBlueprint\x18\x07 \x02(\x08"1\n\x0e\x41ppCameraFrame\x12\r\n\x05\x66rame\x18\x01 \x02(\r\x12\x10\n\x08jpgImage\x18\x02 \x02(\x0c"K\n\x0e\x41ppTeamChanged\x12\x10\n\x08playerId\x18\x01 \x02(\x04\x12\'\n\x08teamInfo\x18\x02 \x02(\x0b\x32\x15.rustplus.AppTeamInfo";\n\x0e\x41ppTeamMessage\x12)\n\x07message\x18\x01 \x02(\x0b\x32\x18.rustplus.AppChatMessage"Q\n\x10\x41ppEntityChanged\x12\x10\n\x08\x65ntityId\x18\x01 \x02(\r\x12+\n\x07payload\x18\x02 \x02(\x0b\x32\x1a.rustplus.AppEntityPayload*:\n\rAppEntityType\x12\n\n\x06Switch\x10\x01\x12\t\n\x05\x41larm\x10\x02\x12\x12\n\x0eStorageMonitor\x10\x03*\x8b\x01\n\rAppMarkerType\x12\n\n\x06Player\x10\x01\x12\r\n\tExplosion\x10\x02\x12\x12\n\x0eVendingMachine\x10\x03\x12\x08\n\x04\x43H47\x10\x04\x12\r\n\tCargoShip\x10\x05\x12\t\n\x05\x43rate\x10\x06\x12\x11\n\rGenericRadius\x10\x07\x12\x14\n\x10PatrolHelicopter\x10\x08'
)

_APPENTITYTYPE = DESCRIPTOR.enum_types_by_name["AppEntityType"]
AppEntityType = enum_type_wrapper.EnumTypeWrapper(_APPENTITYTYPE)
_APPMARKERTYPE = DESCRIPTOR.enum_types_by_name["AppMarkerType"]
AppMarkerType = enum_type_wrapper.EnumTypeWrapper(_APPMARKERTYPE)
Switch = 1
Alarm = 2
StorageMonitor = 3
Player = 1
Explosion = 2
VendingMachine = 3
CH47 = 4
CargoShip = 5
Crate = 6
GenericRadius = 7
PatrolHelicopter = 8

_APPMESSAGE = DESCRIPTOR.message_types_by_name["AppMessage"]
_APPREQUEST = DESCRIPTOR.message_types_by_name["AppRequest"]
_APPSENDMESSAGE = DESCRIPTOR.message_types_by_name["AppSendMessage"]
_APPSETENTITYVALUE = DESCRIPTOR.message_types_by_name["AppSetEntityValue"]
_APPCAMERAFRAMEREQUEST = DESCRIPTOR.message_types_by_name["AppCameraFrameRequest"]
_APPPROMOTETOLEADER = DESCRIPTOR.message_types_by_name["AppPromoteToLeader"]
_APPRESPONSE = DESCRIPTOR.message_types_by_name["AppResponse"]
_APPBROADCAST = DESCRIPTOR.message_types_by_name["AppBroadcast"]
_APPEMPTY = DESCRIPTOR.message_types_by_name["AppEmpty"]
_APPSUCCESS = DESCRIPTOR.message_types_by_name["AppSuccess"]
_APPERROR = DESCRIPTOR.message_types_by_name["AppError"]
_APPINFO = DESCRIPTOR.message_types_by_name["AppInfo"]
_APPTIME = DESCRIPTOR.message_types_by_name["AppTime"]
_APPMAP = DESCRIPTOR.message_types_by_name["AppMap"]
_APPMAP_MONUMENT = _APPMAP.nested_types_by_name["Monument"]
_APPTEAMINFO = DESCRIPTOR.message_types_by_name["AppTeamInfo"]
_APPTEAMINFO_MEMBER = _APPTEAMINFO.nested_types_by_name["Member"]
_APPTEAMINFO_NOTE = _APPTEAMINFO.nested_types_by_name["Note"]
_APPTEAMCHAT = DESCRIPTOR.message_types_by_name["AppTeamChat"]
_APPCHATMESSAGE = DESCRIPTOR.message_types_by_name["AppChatMessage"]
_APPENTITYINFO = DESCRIPTOR.message_types_by_name["AppEntityInfo"]
_APPENTITYPAYLOAD = DESCRIPTOR.message_types_by_name["AppEntityPayload"]
_APPENTITYPAYLOAD_ITEM = _APPENTITYPAYLOAD.nested_types_by_name["Item"]
_APPFLAG = DESCRIPTOR.message_types_by_name["AppFlag"]
_APPMAPMARKERS = DESCRIPTOR.message_types_by_name["AppMapMarkers"]
_VECTOR4 = DESCRIPTOR.message_types_by_name["Vector4"]
_APPMARKER = DESCRIPTOR.message_types_by_name["AppMarker"]
_APPMARKER_SELLORDER = _APPMARKER.nested_types_by_name["SellOrder"]
_APPCAMERAFRAME = DESCRIPTOR.message_types_by_name["AppCameraFrame"]
_APPTEAMCHANGED = DESCRIPTOR.message_types_by_name["AppTeamChanged"]
_APPTEAMMESSAGE = DESCRIPTOR.message_types_by_name["AppTeamMessage"]
_APPENTITYCHANGED = DESCRIPTOR.message_types_by_name["AppEntityChanged"]
AppMessage = _reflection.GeneratedProtocolMessageType(
    "AppMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPMESSAGE,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppMessage)
    },
)
_sym_db.RegisterMessage(AppMessage)

AppRequest = _reflection.GeneratedProtocolMessageType(
    "AppRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPREQUEST,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppRequest)
    },
)
_sym_db.RegisterMessage(AppRequest)

AppSendMessage = _reflection.GeneratedProtocolMessageType(
    "AppSendMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPSENDMESSAGE,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppSendMessage)
    },
)
_sym_db.RegisterMessage(AppSendMessage)

AppSetEntityValue = _reflection.GeneratedProtocolMessageType(
    "AppSetEntityValue",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPSETENTITYVALUE,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppSetEntityValue)
    },
)
_sym_db.RegisterMessage(AppSetEntityValue)

AppCameraFrameRequest = _reflection.GeneratedProtocolMessageType(
    "AppCameraFrameRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPCAMERAFRAMEREQUEST,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppCameraFrameRequest)
    },
)
_sym_db.RegisterMessage(AppCameraFrameRequest)

AppPromoteToLeader = _reflection.GeneratedProtocolMessageType(
    "AppPromoteToLeader",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPPROMOTETOLEADER,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppPromoteToLeader)
    },
)
_sym_db.RegisterMessage(AppPromoteToLeader)

AppResponse = _reflection.GeneratedProtocolMessageType(
    "AppResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPRESPONSE,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppResponse)
    },
)
_sym_db.RegisterMessage(AppResponse)

AppBroadcast = _reflection.GeneratedProtocolMessageType(
    "AppBroadcast",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPBROADCAST,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppBroadcast)
    },
)
_sym_db.RegisterMessage(AppBroadcast)

AppEmpty = _reflection.GeneratedProtocolMessageType(
    "AppEmpty",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPEMPTY,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppEmpty)
    },
)
_sym_db.RegisterMessage(AppEmpty)

AppSuccess = _reflection.GeneratedProtocolMessageType(
    "AppSuccess",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPSUCCESS,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppSuccess)
    },
)
_sym_db.RegisterMessage(AppSuccess)

AppError = _reflection.GeneratedProtocolMessageType(
    "AppError",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPERROR,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppError)
    },
)
_sym_db.RegisterMessage(AppError)

AppInfo = _reflection.GeneratedProtocolMessageType(
    "AppInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPINFO,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppInfo)
    },
)
_sym_db.RegisterMessage(AppInfo)

AppTime = _reflection.GeneratedProtocolMessageType(
    "AppTime",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPTIME,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppTime)
    },
)
_sym_db.RegisterMessage(AppTime)

AppMap = _reflection.GeneratedProtocolMessageType(
    "AppMap",
    (_message.Message,),
    {
        "Monument": _reflection.GeneratedProtocolMessageType(
            "Monument",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPMAP_MONUMENT,
                "__module__": "rustplus_pb2"
                # @@protoc_insertion_point(class_scope:rustplus.AppMap.Monument)
            },
        ),
        "DESCRIPTOR": _APPMAP,
        "__module__": "rustplus_pb2"
        # @@protoc_insertion_point(class_scope:rustplus.AppMap)
    },
)
_sym_db.RegisterMessage(AppMap)
_sym_db.RegisterMessage(AppMap.Monument)

AppTeamInfo = _reflection.GeneratedProtocolMessageType(
    "AppTeamInfo",
    (_message.Message,),
    {
        "Member": _reflection.GeneratedProtocolMessageType(
            "Member",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPTEAMINFO_MEMBER,
                "__module__": "rustplus_pb2"
                # @@protoc_insertion_point(class_scope:rustplus.AppTeamInfo.Member)
            },
        ),
        "Note": _reflection.GeneratedProtocolMessageType(
            "Note",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPTEAMINFO_NOTE,
                "__module__": "rustplus_pb2"
                # @@protoc_insertion_point(class_scope:rustplus.AppTeamInfo.Note)
            },
        ),
        "DESCRIPTOR": _APPTEAMINFO,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppTeamInfo)
    },
)
_sym_db.RegisterMessage(AppTeamInfo)
_sym_db.RegisterMessage(AppTeamInfo.Member)
_sym_db.RegisterMessage(AppTeamInfo.Note)

AppTeamChat = _reflection.GeneratedProtocolMessageType(
    "AppTeamChat",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPTEAMCHAT,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppTeamChat)
    },
)
_sym_db.RegisterMessage(AppTeamChat)

AppChatMessage = _reflection.GeneratedProtocolMessageType(
    "AppChatMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPCHATMESSAGE,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppChatMessage)
    },
)
_sym_db.RegisterMessage(AppChatMessage)

AppEntityInfo = _reflection.GeneratedProtocolMessageType(
    "AppEntityInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPENTITYINFO,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppEntityInfo)
    },
)
_sym_db.RegisterMessage(AppEntityInfo)

AppEntityPayload = _reflection.GeneratedProtocolMessageType(
    "AppEntityPayload",
    (_message.Message,),
    {
        "Item": _reflection.GeneratedProtocolMessageType(
            "Item",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPENTITYPAYLOAD_ITEM,
                "__module__": "rustplus_proto"
                # @@protoc_insertion_point(class_scope:rustplus.AppEntityPayload.Item)
            },
        ),
        "DESCRIPTOR": _APPENTITYPAYLOAD,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppEntityPayload)
    },
)
_sym_db.RegisterMessage(AppEntityPayload)
_sym_db.RegisterMessage(AppEntityPayload.Item)

AppFlag = _reflection.GeneratedProtocolMessageType(
    "AppFlag",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPFLAG,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppFlag)
    },
)
_sym_db.RegisterMessage(AppFlag)

AppMapMarkers = _reflection.GeneratedProtocolMessageType(
    "AppMapMarkers",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPMAPMARKERS,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppMapMarkers)
    },
)
_sym_db.RegisterMessage(AppMapMarkers)

Vector4 = _reflection.GeneratedProtocolMessageType(
    "Vector4",
    (_message.Message,),
    {
        "DESCRIPTOR": _VECTOR4,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.Vector4)
    },
)
_sym_db.RegisterMessage(Vector4)

AppMarker = _reflection.GeneratedProtocolMessageType(
    "AppMarker",
    (_message.Message,),
    {
        "SellOrder": _reflection.GeneratedProtocolMessageType(
            "SellOrder",
            (_message.Message,),
            {
                "DESCRIPTOR": _APPMARKER_SELLORDER,
                "__module__": "rustplus_proto"
                # @@protoc_insertion_point(class_scope:rustplus.AppMarker.SellOrder)
            },
        ),
        "DESCRIPTOR": _APPMARKER,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppMarker)
    },
)
_sym_db.RegisterMessage(AppMarker)
_sym_db.RegisterMessage(AppMarker.SellOrder)

AppCameraFrame = _reflection.GeneratedProtocolMessageType(
    "AppCameraFrame",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPCAMERAFRAME,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppCameraFrame)
    },
)
_sym_db.RegisterMessage(AppCameraFrame)

AppTeamChanged = _reflection.GeneratedProtocolMessageType(
    "AppTeamChanged",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPTEAMCHANGED,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppTeamChanged)
    },
)
_sym_db.RegisterMessage(AppTeamChanged)

AppTeamMessage = _reflection.GeneratedProtocolMessageType(
    "AppTeamMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPTEAMMESSAGE,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppTeamMessage)
    },
)
_sym_db.RegisterMessage(AppTeamMessage)

AppEntityChanged = _reflection.GeneratedProtocolMessageType(
    "AppEntityChanged",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPENTITYCHANGED,
        "__module__": "rustplus_proto"
        # @@protoc_insertion_point(class_scope:rustplus.AppEntityChanged)
    },
)
_sym_db.RegisterMessage(AppEntityChanged)

if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._options = None
    _APPENTITYTYPE._serialized_start = 3828
    _APPENTITYTYPE._serialized_end = 3886
    _APPMARKERTYPE._serialized_start = 3889
    _APPMARKERTYPE._serialized_end = 4028
    _APPMESSAGE._serialized_start = 28
    _APPMESSAGE._serialized_end = 124
    _APPREQUEST._serialized_start = 127
    _APPREQUEST._serialized_end = 794
    _APPSENDMESSAGE._serialized_start = 796
    _APPSENDMESSAGE._serialized_end = 829
    _APPSETENTITYVALUE._serialized_start = 831
    _APPSETENTITYVALUE._serialized_end = 865
    _APPCAMERAFRAMEREQUEST._serialized_start = 867
    _APPCAMERAFRAMEREQUEST._serialized_end = 925
    _APPPROMOTETOLEADER._serialized_start = 927
    _APPPROMOTETOLEADER._serialized_end = 964
    _APPRESPONSE._serialized_start = 967
    _APPRESPONSE._serialized_end = 1416
    _APPBROADCAST._serialized_start = 1419
    _APPBROADCAST._serialized_end = 1578
    _APPEMPTY._serialized_start = 1580
    _APPEMPTY._serialized_end = 1590
    _APPSUCCESS._serialized_start = 1592
    _APPSUCCESS._serialized_end = 1604
    _APPERROR._serialized_start = 1606
    _APPERROR._serialized_end = 1631
    _APPINFO._serialized_start = 1634
    _APPINFO._serialized_end = 1827
    _APPTIME._serialized_start = 1829
    _APPTIME._serialized_end = 1930
    _APPMAP._serialized_start = 1933
    _APPMAP._serialized_end = 2126
    _APPMAP_MONUMENT._serialized_start = 2079
    _APPMAP_MONUMENT._serialized_end = 2126
    _APPTEAMINFO._serialized_start = 2129
    _APPTEAMINFO._serialized_end = 2491
    _APPTEAMINFO_MEMBER._serialized_start = 2313
    _APPTEAMINFO_MEMBER._serialized_end = 2447
    _APPTEAMINFO_NOTE._serialized_start = 2449
    _APPTEAMINFO_NOTE._serialized_end = 2491
    _APPTEAMCHAT._serialized_start = 2493
    _APPTEAMCHAT._serialized_end = 2550
    _APPCHATMESSAGE._serialized_start = 2552
    _APPCHATMESSAGE._serialized_end = 2645
    _APPENTITYINFO._serialized_start = 2647
    _APPENTITYINFO._serialized_end = 2746
    _APPENTITYPAYLOAD._serialized_start = 2749
    _APPENTITYPAYLOAD._serialized_end = 2964
    _APPENTITYPAYLOAD_ITEM._serialized_start = 2899
    _APPENTITYPAYLOAD_ITEM._serialized_end = 2964
    _APPFLAG._serialized_start = 2966
    _APPFLAG._serialized_end = 2990
    _APPMAPMARKERS._serialized_start = 2992
    _APPMAPMARKERS._serialized_end = 3045
    _VECTOR4._serialized_start = 3047
    _VECTOR4._serialized_end = 3100
    _APPMARKER._serialized_start = 3103
    _APPMARKER._serialized_end = 3554
    _APPMARKER_SELLORDER._serialized_start = 3391
    _APPMARKER_SELLORDER._serialized_end = 3554
    _APPCAMERAFRAME._serialized_start = 3556
    _APPCAMERAFRAME._serialized_end = 3605
    _APPTEAMCHANGED._serialized_start = 3607
    _APPTEAMCHANGED._serialized_end = 3682
    _APPTEAMMESSAGE._serialized_start = 3684
    _APPTEAMMESSAGE._serialized_end = 3743
    _APPENTITYCHANGED._serialized_start = 3745
    _APPENTITYCHANGED._serialized_end = 3826
# @@protoc_insertion_point(module_scope)
