from .exceptions import (
    RateLimitError,
    ServerNotResponsiveError,
    CommandsNotEnabledError,
    ResponseNotReceivedError,
    PrefixNotDefinedError,
    ImageError,
    ClientNotConnectedError,
    RequestError,
    SmartDeviceRegistrationError,
)
